@@ -146,7 +146,11 @@ class TestBasicCalibrationModel:
             DifferentEM.load('save_load_test.json')
         return
 
-    def test_save_and_load_attributes(self):
+    @pytest.mark.parametrize("ndim", [1, 2, 3])
+    def test_save_and_load_attributes(self, ndim):
+        shape = tuple(3 + numpy.arange(ndim))
+        assert len(shape) == ndim
+
         em = _TestModel()
         em.theta_guess = (1,1,1)
         em.theta_fitted = (1,2,3)
@@ -156,8 +160,8 @@ class TestBasicCalibrationModel:
             (0, 5),
             (0, 10)
         )
-        em.cal_independent = numpy.linspace(0, 10, 7)
-        em.cal_dependent = numpy.random.normal(em.cal_independent)
+        em.cal_independent = numpy.random.uniform(0, 10, size=shape)
+        em.cal_dependent = numpy.random.normal(size=len(em.cal_independent))
 
         # save and load
         em.save('save_load_test.json')
@@ -824,7 +828,6 @@ class TestBasePolynomialModelT:
         pass
 
 
-
 class TestBaseAsymmetricLogisticModelT:
     def test_predict_dependent(self):
         x = numpy.array([1,2,3])
@@ -893,6 +896,42 @@ class TestOptimization:
         assert "3 elements" in caplog.text
         pass
 
+    def test_finite_masking_multivariate(self, caplog):
+        x = numpy.random.normal(size=(4, 5))
+        y = numpy.sum(x ** 2, axis=1)
+        assert x.ndim == 2
+        assert x.shape == (4, 5)
+        assert y.shape == (4,)
+
+        result = calibr8.optimization._mask_and_warn_inf_or_nan(x, y)
+        numpy.testing.assert_array_equal(result[0], x)
+        numpy.testing.assert_array_equal(result[1], y)
+
+        x[1, 1] = numpy.inf
+        with caplog.at_level(logging.WARNING):
+            result = calibr8.optimization._mask_and_warn_inf_or_nan(x, y, on="x")
+        assert len(result[0]) == 3
+        assert len(result[1]) == 3
+        assert "1 elements" in caplog.text
+
+        y[[0, 3]] = numpy.nan
+        with caplog.at_level(logging.WARNING):
+            result = calibr8.optimization._mask_and_warn_inf_or_nan(x, y, on="y")
+        assert len(result[0]) == 2
+        assert len(result[1]) == 2
+        assert "2 elements" in caplog.text
+
+        with caplog.at_level(logging.WARNING):
+            result = calibr8.optimization._mask_and_warn_inf_or_nan(x, y)
+        assert len(result[0]) == 1
+        assert len(result[1]) == 1
+        assert "3 elements" in caplog.text
+
+        # higher dimensionality inputs are not supported:
+        with pytest.raises(ValueError, match="4-dimensional"):
+            calibr8.optimization._mask_and_warn_inf_or_nan(x[:, :, None, None], y)
+        pass
+
     def test_fit_checks_guess_and_bounds_count(self):
         theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
         common = dict(model=em, independent=x, dependent=y)
